class ChunksController < ApplicationController
  layout nil

  before_action :set_learning_object

  #GET /chunk
  def show
    chunk = resumable_chunk params[:resumableChunkNumber]

    if File.exists?(chunk)
      post_file_and_create_thumbnail @learning_object, resumable_filename if last_chunk?
      #Let resumable.js know this chunk already exists
      render :nothing => true, :status => 200
    else
      #Let resumable.js know this chunk doesnt exists and needs to be uploaded
      render :nothing => true, :status => 404
    end

  end

  #POST /chunk
  def create
    #chunk path based on the parameters
    chunk = resumable_chunk chunk_number

    #Create chunks directory when not present on system
    if !File.directory?(dir)
      FileUtils.mkdir(dir, :mode => 0700)
    end

    #Move the uploaded chunk to the directory
    FileUtils.mv params[:file].tempfile, chunk

    #Concatenate all the partial files into the original file
    #When all chunks are uploaded
    if last_chunk?
      #Create a target file
      File.open(resumable_filename, "a") do |target|
        #Loop trough the chunks
        for i in 1..params[:resumableChunkNumber].to_i
          #Select the chunk
          chunk = File.open(resumable_chunk(i), 'r').read

          #Write chunk into target file
          chunk.each_line do |line|
            target << line
          end

          #Deleting chunk
          FileUtils.rm resumable_chunk(i), :force => true
        end
        puts "File saved to #{resumable_filename}"
      end

      post_file_and_create_thumbnail @learning_object, resumable_filename
    end

    render nothing: true, status: 200
  end

  private

  def post_file_and_create_thumbnail(learning_object, filename)
    publisher = LearningObjectPublisher.new(DspaceService.create_client)
    publisher.post learning_object, filename
  end

  def last_chunk?
    chunk_number == total_chunks
  end

  def chunk_size
    params[:resumableChunkSize].to_i
  end

  def total_chunks
    params[:resumableTotalChunks].to_i
  end

  def chunk_number
    params[:resumableChunkNumber].to_i
  end

  def resumable_chunk(part)
    "#{resumable_filename}.part#{part}"
  end

  def resumable_filename
    "#{dir}/#{params[:resumableFilename]}"
  end

  def dir
    "/tmp/#{params[:resumableIdentifier]}"
  end

  def set_learning_object
    @learning_object = LearningObject.find params[:learning_object_id]
  end
end
