class Management::InstitutionsController < ManagementController
  before_action :set_institution, only: [:show, :edit, :update, :destroy, :add_user, :remove_user]

  # GET /management/institutions
  # GET /management/institutions.json
  def index
    @institutions = Institution.all
  end

  # GET /management/institutions/1
  # GET /management/institutions/1.json
  def show
  end

  # GET /management/institutions/new
  def new
    @institution = Institution.new
  end

  # GET /management/institutions/1/edit
  def edit
  end

  # POST /management/institutions
  # POST /management/institutions.json
  def create
    @institution = Institution.new(institution_params)

    respond_to do |format|
      if @institution.save
        format.html { redirect_to [:management, @institution], notice: 'Instituição criada com sucesso.' }
        format.json { render :show, status: :created, location: @institution }
      else
        format.html { render :new }
        format.json { render json: @institution.errors, status: :unprocessable_entity }
      end
    end
  end

  # POST /management/institutions/:id/user/:user_id
  # add user to institution
  def add_user
    user = User.find(params[:user_id])

    unless user.blank?
      @institution.users << user
      @institution.save
    end

    render json: true
  end

  # DELETE /management/institutions/:id/user/:user_id
  # remove user from institution
  def remove_user
    @institution.users.delete(params[:user_id])

    render json: true
  end

  # PATCH/PUT /management/institutions/1
  # PATCH/PUT /management/institutions/1.json
  def update
    respond_to do |format|
      if @institution.update institution_params
        format.html { redirect_to [:management, @institution], notice: 'Instituição modificada com sucesso.' }
        format.json { render :show, status: :ok, location: @institution }
      else
        format.html { render :edit }
        format.json { render json: @institution.errors, status: :unprocessable_entity }
      end
    end
  end

  # DELETE /management/institutions/1
  # DELETE /management/institutions/1.json
  def destroy
    @institution.destroy
    respond_to do |format|
      format.html { redirect_to management_institutions_url, notice: 'Instituição deletada com sucesso.' }
      format.json { head :no_content }
    end
  end

  private
  # Use callbacks to share common setup or constraints between actions.
  def set_institution
    @institution = Institution.find params[:id]
  end

  # Never trust parameters from the scary internet, only allow the white list through.
  def institution_params
    params.require(:institution).permit(:name, :city, :country, :address, :description)
  end
end
