require 'uri'
require 'screencap'

class ThumbnailGenerateWorker
  include Sidekiq::Worker

  def perform(attachment_id, media_path = nil)
    attachment = ::LearningObject::Attachment.find(attachment_id)
    return false if attachment.nil?

    media = media_path.nil? ? bitstream_download(attachment.id_dspace) : create_media(media_path)

    thumbnail = thumbnail_service.create_thumbnail(media) unless media.blank?

    attachment.update(thumbnail: thumbnail) unless thumbnail.blank?
  end

  private

  def create_media(path)
    return ::Screencap::Fetcher.new(path) if path =~ URI::regexp
    File.open path
  end

  def bitstream_download(id)
    client = DspaceService.create_client
    client.bitstreams.retrieve(id: id).open
  end

  def thumbnail_service
    @@thumbnailService ||= ThumbnailService.new(generators)
  end

  def generators
    [
        Thumbnail::Strategies::VideoThumbnailGenerator.new,
        Thumbnail::Strategies::ImageThumbnailGenerator.new,
        Thumbnail::Strategies::PdfThumbnailGenerator.new,
        Thumbnail::Strategies::UrlThumbnailGenerator.new
    ]
  end
end
